<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>właśnie teraz</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 nowa wiadomość</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 minut temu</translation>
    </message>
</context>
</TS>